@@ -33,6 +33,7 @@ def test_constructor_options():
         api_core_version="3",
         gapic_version="4",
         client_library_version="5",
+        user_agent="6"
     )
 
     assert info.python_version == "1"
@@ -40,6 +41,7 @@ def test_constructor_options():
     assert info.api_core_version == "3"
     assert info.gapic_version == "4"
     assert info.client_library_version == "5"
+    assert info.user_agent == "6"
 
 
 def test_to_user_agent_minimal():
@@ -59,11 +61,12 @@ def test_to_user_agent_full():
         api_core_version="3",
         gapic_version="4",
         client_library_version="5",
+        user_agent="app-name/1.0",
     )
 
     user_agent = info.to_user_agent()
 
-    assert user_agent == "gl-python/1 grpc/2 gax/3 gapic/4 gccl/5"
+    assert user_agent == "app-name/1.0 gl-python/1 grpc/2 gax/3 gapic/4 gccl/5"
 
 
 def test_to_grpc_metadata():
